IamErrorCode

Enum IamErrorCode 

#[non_exhaustive]
pub enum IamErrorCode {
Show 21 variants ConcurrentModificationException, DeleteConflict, DeleteConflictException, EntityAlreadyExists, EntityAlreadyExistsException, EntityTemporarilyUnmodifiableException, InvalidAction, InvalidInput, InvalidInputException, LimitExceeded, LimitExceededException, MalformedPolicyDocument, MalformedPolicyDocumentException, MissingAction, NoSuchEntity, NoSuchEntityException, PolicyEvaluationException, PolicyNotAttachableException, ServiceFailure, ServiceFailureException, UnmodifiableEntityException,
}
Well-known IAM error codes.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ConcurrentModificationException

ConcurrentModificationException error.



DeleteConflict

DeleteConflict error.



DeleteConflictException

DeleteConflictException error.



EntityAlreadyExists

EntityAlreadyExists error.



EntityAlreadyExistsException

EntityAlreadyExistsException error.



EntityTemporarilyUnmodifiableException

EntityTemporarilyUnmodifiableException error.



InvalidAction

InvalidAction error.



InvalidInput

InvalidInput error.



InvalidInputException

InvalidInputException error.



LimitExceeded

LimitExceeded error.



LimitExceededException

LimitExceededException error.



MalformedPolicyDocument

MalformedPolicyDocument error.



MalformedPolicyDocumentException

MalformedPolicyDocumentException error.



MissingAction

MissingAction error.



NoSuchEntity

NoSuchEntity error.



NoSuchEntityException

NoSuchEntityException error.



PolicyEvaluationException

PolicyEvaluationException error.



PolicyNotAttachableException

PolicyNotAttachableException error.



ServiceFailure

ServiceFailure error.



ServiceFailureException

ServiceFailureException error.



UnmodifiableEntityException

UnmodifiableEntityException error.

Implementations

Source

impl IamErrorCode

pub fn error_type(&self) -> &'static str

Returns the short error type string for the JSON __type field.

pub fn as_str(&self) -> &'static str

Returns the short error code string.

pub fn code(&self) -> &'static str

Returns the error code string for the XML <Code> element.

pub fn fault(&self) -> &'static str

Returns whether this is a Sender or Receiver fault for XML <Type>.

pub fn status_code(&self) -> StatusCode

HTTP status code for this error.

pub fn default_status_code(&self) -> StatusCode

Returns the default HTTP status code for this error.