#[non_exhaustive]pub enum IamErrorCode {
Show 21 variants
ConcurrentModificationException,
DeleteConflict,
DeleteConflictException,
EntityAlreadyExists,
EntityAlreadyExistsException,
EntityTemporarilyUnmodifiableException,
InvalidAction,
InvalidInput,
InvalidInputException,
LimitExceeded,
LimitExceededException,
MalformedPolicyDocument,
MalformedPolicyDocumentException,
MissingAction,
NoSuchEntity,
NoSuchEntityException,
PolicyEvaluationException,
PolicyNotAttachableException,
ServiceFailure,
ServiceFailureException,
UnmodifiableEntityException,
}Expand description
Well-known IAM error codes.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ConcurrentModificationException
ConcurrentModificationException error.
DeleteConflict
DeleteConflict error.
DeleteConflictException
DeleteConflictException error.
EntityAlreadyExists
EntityAlreadyExists error.
EntityAlreadyExistsException
EntityAlreadyExistsException error.
EntityTemporarilyUnmodifiableException
EntityTemporarilyUnmodifiableException error.
InvalidAction
InvalidAction error.
InvalidInput
InvalidInput error.
InvalidInputException
InvalidInputException error.
LimitExceeded
LimitExceeded error.
LimitExceededException
LimitExceededException error.
MalformedPolicyDocument
MalformedPolicyDocument error.
MalformedPolicyDocumentException
MalformedPolicyDocumentException error.
MissingAction
MissingAction error.
NoSuchEntity
NoSuchEntity error.
NoSuchEntityException
NoSuchEntityException error.
PolicyEvaluationException
PolicyEvaluationException error.
PolicyNotAttachableException
PolicyNotAttachableException error.
ServiceFailure
ServiceFailure error.
ServiceFailureException
ServiceFailureException error.
UnmodifiableEntityException
UnmodifiableEntityException error.
Implementations
Sourceimpl IamErrorCode
impl IamErrorCode
Sourcepub fn error_type(&self) -> &'static str
pub fn error_type(&self) -> &'static str
Returns the short error type string for the JSON __type field.
Sourcepub fn fault(&self) -> &'static str
pub fn fault(&self) -> &'static str
Returns whether this is a Sender or Receiver fault for XML <Type>.
Sourcepub fn status_code(&self) -> StatusCode
pub fn status_code(&self) -> StatusCode
HTTP status code for this error.
Sourcepub fn default_status_code(&self) -> StatusCode
pub fn default_status_code(&self) -> StatusCode
Returns the default HTTP status code for this error.